summaryrefslogtreecommitdiffstats
path: root/kplayer/kplayer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplayer/kplayer.h')
-rw-r--r--kplayer/kplayer.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/kplayer/kplayer.h b/kplayer/kplayer.h
index 003f39b..a4409a1 100644
--- a/kplayer/kplayer.h
+++ b/kplayer/kplayer.h
@@ -20,8 +20,8 @@
#include <config.h>
#endif
-#include <kaction.h>
-#include <kmainwindow.h>
+#include <tdeaction.h>
+#include <tdemainwindow.h>
#include <kuniqueapplication.h>
#include "kplayerengine.h"
@@ -33,7 +33,7 @@ class KPlayerNodeView;
class KPlayerPlaylist;
class KPlayerWorkspace;
class KStatusBarLabel;
-class KToggleAction;
+class TDEToggleAction;
class KURL;
class TQMenuData;
@@ -52,7 +52,7 @@ class TQMenuData;
/** The KPlayer main window class.
*@author kiriuja
*/
-class KPlayer : public KMainWindow
+class KPlayer : public TDEMainWindow
{
Q_OBJECT
@@ -65,7 +65,7 @@ class KPlayer : public KMainWindow
} Toolbar;
public:
/** Constructor. Parameters are passed to KMainWindow constructor. */
KPlayer (TQWidget* parent=0, const char *name=0);
/** Destructor. */
virtual ~KPlayer() { }
@@ -84,7 +84,7 @@ public:
{ return engine() -> process(); }
/** Main config. */
- KConfig* config (void) const
+ TDEConfig* config (void) const
{ return KPlayerEngine::engine() -> config(); }
/** Playlist. */
@@ -160,11 +160,11 @@ protected:
/** Read general options again and initialize all variables like the recent file list. */
void readOptions (void);
/** Saves the current URLs during session end to the session config file.
- @see KMainWindow#saveProperties */
- //virtual void saveProperties (KConfig*) const;
+ @see TDEMainWindow#saveProperties */
+ //virtual void saveProperties (TDEConfig*) const;
/** Restores the URLs from the session config file.
- @see KMainWindow#readProperties */
- //virtual void readProperties (KConfig*);
+ @see TDEMainWindow#readProperties */
+ //virtual void readProperties (TDEConfig*);
/** Enables or disables player actions. */
void enablePlayerActions (void);
@@ -194,7 +194,7 @@ protected:
/** Changes the statusbar contents for the standard label permanently, used to indicate current actions. */
void setStatusText (const TQString&);
/** Processes the widget events. Passes them on to KMainWindow. */
//virtual bool event (TQEvent*);
/** Sets the window geometry on the initial show event. */
virtual void showEvent (TQShowEvent*);
@@ -215,11 +215,11 @@ protected:
virtual void closeEvent (TQCloseEvent*);
/** Retrieves an action from the actionCollection by name. */
- KAction* action (const char* name) const
+ TDEAction* action (const char* name) const
{ return actionCollection() -> action (name); }
/** Retrieves a toggle action from the actionCollection by name. */
- KToggleAction* toggleAction (const char* name) const
- { return (KToggleAction*) action (name); }
+ TDEToggleAction* toggleAction (const char* name) const
+ { return (TDEToggleAction*) action (name); }
/** Rearranges child windows and clears events. */
void activateLayout (void);
@@ -65,7 +65,7 @@ class KPlayer : public KMainWindow
} Toolbar;
public:
- /** Constructor. Parameters are passed to KMainWindow constructor. */
+ /** Constructor. Parameters are passed to TDEMainWindow constructor. */
KPlayer (TQWidget* parent=0, const char *name=0);
/** Destructor. */
@@ -194,7 +194,7 @@ protected:
/** Changes the statusbar contents for the standard label permanently, used to indicate current actions. */
void setStatusText (const TQString&);
- /** Processes the widget events. Passes them on to KMainWindow. */
+ /** Processes the widget events. Passes them on to TDEMainWindow. */
//virtual bool event (TQEvent*);
/** Sets the window geometry on the initial show event. */